==> ropt-0.20.2.tar.gz: ropt-0.20.2/docs/snippets/scipy.md <==

| Method | Method Options |
|--------|----------------|
|[Nelder-Mead](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-neldermead.html)|disp, maxiter, maxfev, xatol, fatol, adaptive|
|[Powell](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-powell.html)|disp, maxiter, maxfev, xtol, ftol|
|[CG](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-cg.html)|disp, maxiter, gtol, norm, eps, finite_diff_rel_step, c1, c2|
|[BFGS](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-bfgs.html)|disp, maxiter, gtol, norm, eps, finite_diff_rel_step, xrtol, c1, c2|
|[Newton-CG](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-newtoncg.html)|disp, maxiter, xtol, eps, c1, c2|
|[L-BFGS-B](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-lbfgsb.html)|disp, maxiter, maxcor, ftol, gtol, eps, maxfun, iprint, maxls, finite_diff_rel_step|
|[TNC](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-tnc.html)|disp, maxfun, eps, scale, offset, maxCGit, eta, stepmx, accuracy, minfev, ftol, xtol, gtol, rescale, finite_diff_rel_step|
|[COBYLA](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-cobyla.html)|disp, maxiter, rhobeg, tol, catol|
|[SLSQP](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-slsqp.html)|disp, maxiter, ftol, eps, finite_diff_rel_step|
|[differential_evolution](https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.differential_evolution.html)|disp, maxiter, strategy, popsize, tol, mutation, recombination, seed, polish, init, atol, updating|

==> ropt-0.22.2.tar.gz: ropt-0.22.2/docs/snippets/scipy.md <==

| Method | Method Options |
|--------|----------------|
|[Nelder-Mead](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-neldermead.html)|disp, maxiter, maxfev, xatol, fatol, adaptive|
|[Powell](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-powell.html)|disp, maxiter, maxfev, xtol, ftol|
|[CG](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-cg.html)|disp, maxiter, gtol, norm, eps, finite_diff_rel_step, c1, c2|
|[BFGS](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-bfgs.html)|disp, maxiter, gtol, norm, eps, finite_diff_rel_step, xrtol, c1, c2|
|[Newton-CG](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-newtoncg.html)|disp, maxiter, xtol, eps, c1, c2|
|[L-BFGS-B](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-lbfgsb.html)|disp, maxiter, maxcor, ftol, gtol, eps, maxfun, iprint, maxls, finite_diff_rel_step|
|[TNC](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-tnc.html)|disp, maxfun, eps, scale, offset, maxCGit, eta, stepmx, accuracy, minfev, ftol, xtol, gtol, rescale, finite_diff_rel_step|
|[COBYLA](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-cobyla.html)|disp, maxiter, rhobeg, tol, catol|
|[SLSQP](https://docs.scipy.org/doc/scipy/reference/optimize.minimize-slsqp.html)|disp, maxiter, ftol, eps, finite_diff_rel_step|
|[differential_evolution](https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.differential_evolution.html)|disp, maxiter, strategy, popsize, tol, mutation, recombination, rng, polish, init, atol, updating|
